import { AddressAutofillFeatureSuggestion, AddressAutofillOptions, AddressAutofillRetrieveResponse, AddressAutofillSuggestion, AddressAutofillSuggestionResponse } from '@mapbox/search-js-core';
import { MapboxSearchListbox } from './MapboxSearchListbox';
import { HTMLScopedElement } from './HTMLScopedElement';
import { Theme } from '../theme';
import { MapboxHTMLEvent } from '../MapboxHTMLEvent';
import { AddressConfirmOptions } from './MapboxAddressConfirmation';
import { PopoverOptions } from '../utils/popover';
export declare type MapboxSearchListboxAutofillType = MapboxSearchListbox<AddressAutofillSuggestion>;
declare type AddressAutofillEventTypes = {
    /**
     * Fired when the user is typing in the input and provides a list of suggestions.
     *
     * The underlying response from {@link AddressAutofillCore} is passed as the event's detail.
     *
     * @event suggest
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {AddressAutofillSuggestionResponse}
     * @example
     * ```typescript
     * autofill.addEventListener('suggest', (event) => {
     *   const suggestions = event.detail.suggestions;
     *   // ...
     * });
     * ```
     */
    suggest: MapboxHTMLEvent<AddressAutofillSuggestionResponse>;
    /**
     * Fired when {@link AddressAutofillCore} has errored providing a list of suggestions.
     *
     * The underlying error is passed as the event's detail.
     *
     * @event suggesterror
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {Error}
     * @example
     * ```typescript
     * autofill.addEventListener('suggesterror', (event) => {
     *   const error = event.detail;
     *   // ...
     * });
     * ```
     */
    suggesterror: MapboxHTMLEvent<Error>;
    /**
     * Fired when the user has selected a suggestion, before the form is autofilled.
     *
     * The underlying response from {@link AddressAutofillCore} is passed as the event's detail.
     *
     * @event retrieve
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {AddressAutofillRetrieveResponse}
     * @example
     * ```typescript
     * autofill.addEventListener('retrieve', (event) => {
     *   const featureCollection = event.detail;
     *   // ...
     * });
     * ```
     */
    retrieve: MapboxHTMLEvent<AddressAutofillRetrieveResponse>;
    /**
     * Fired when the user has changed the `<input>` text.
     *
     * The new input value is passed as the event's detail.
     *
     * @event input
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {string}
     * @example
     * ```typescript
     * autofill.addEventListener('input', (event) => {
     *   if (e.target !== e.currentTarget) return;
     *   const searchText = event.detail;
     *   // ...
     * });
     * ```
     */
    input: MapboxHTMLEvent<unknown>;
};
/**
 * `MapboxAddressAutofill`, also available as the element `<mapbox-address-autofill>`,
 * is an element that wraps an address [`<input>`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input/text) element with
 * intelligent, location-aware autocomplete functionality.
 *
 * To use this element, you must have a [Mapbox access token](https://www.mapbox.com/help/create-api-access-token/).
 *
 * This element must be a descendant of a [`<form>`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form) element, and the form
 * must have inputs with proper HTML `autocomplete` attributes. If your application works with browser autofill, you may already have
 * this functionality.
 * - [The HTML autocomplete attribute](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/autocomplete)
 * - [Autofill](https://web.dev/learn/forms/autofill/)
 *
 * @class MapboxAddressAutofill
 * @example
 * <form>
 *   <mapbox-address-autofill access-token="YOUR_MAPBOX_ACCESS_TOKEN">
 *     <input type="text" name="address" autocomplete="shipping street-address" />
 *   </mapbox-address-autofill>
 * </form>
 */
export declare class MapboxAddressAutofill extends HTMLScopedElement<AddressAutofillEventTypes> {
    #private;
    /**
     * This is read by the Web Components API to affect the
     * {@link MapboxAddressAutofill.attributeChangedCallback} below.
     *
     * All of these are passthroughs to the underlying {@link MapboxSearchListbox}.
     *
     * @ignore
     */
    static observedAttributes: string[];
    /**
     * The [Mapbox access token](https://docs.mapbox.com/help/glossary/access-token/) to use for all requests.
     *
     * @name accessToken
     * @instance
     * @memberof MapboxAddressAutofill
     * @example
     * ```typescript
     * autofill.accessToken = 'pk.my-mapbox-access-token';
     * ```
     */
    get accessToken(): string;
    set accessToken(newToken: string);
    /**
     * The `<input>` element wrapped by the autofill component.
     *
     * @name input
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {HTMLInputElement}
     */
    get input(): HTMLInputElement;
    /**
     * Options to pass to the underlying {@link AddressAutofillCore} interface.
     *
     * @name options
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {AddressAutofillOptions}
     * @example
     * ```typescript
     * autofill.options = {
     *  language: 'en',
     *  country: 'US',
     * };
     * ```
     */
    options: Partial<AddressAutofillOptions>;
    /**
     * The {@link Theme} to use for styling the autofill component.
     *
     * @name theme
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {Theme}
     * @example
     * ```typescript
     * autofill.theme = {
     *   variables: {
     *     colorPrimary: 'myBrandRed'
     *   }
     * };
     * ```
     */
    get theme(): Theme;
    set theme(theme: Theme);
    /**
     * The {@link PopoverOptions} to define popover positioning.
     *
     * @name popoverOptions
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {PopoverOptions}
     * @example
     * ```typescript
     * autofill.popoverOptions = {
     *   placement: 'top-start',
     *   flip: true,
     *   offset: 5
     * };
     * ```
     */
    get popoverOptions(): Partial<PopoverOptions>;
    set popoverOptions(newOptions: Partial<PopoverOptions>);
    /**
     * If true, forms autofilled by the browser will prompt the
     * {@link confirmAddress} dialog for user confirmation.
     * An {@link AddressConfirmOptions} object can also be passed
     * to prompt {@link confirmAddress} with custom options.
     * Defaults to false.
     *
     * @name confirmOnBrowserAutofill
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {boolean | AddressConfirmOptions}
     * @example
     * ```typescript
     * autofill.confirmOnBrowserAutofill = {
     *   minimap: true,
     *   skipConfirmModal: (feature) =>
     *     ['exact', 'high'].includes(
     *       feature.properties.match_code.confidence
     *     )
     * };
     * ```
     */
    confirmOnBrowserAutofill: boolean | AddressConfirmOptions;
    /**
     * Enables the browser's autocomplete popup to show during the first two typed characters while Mapbox results are suppressed. Defaults to false.
     *
     * **Note:** Due to varying specifications, efforts to suppress browser autocomplete behavior may not work on all browsers.
     *
     * @name browserAutofillEnabled
     * @instance
     * @memberof MapboxAddressAutofill
     * @type {boolean}
     * @example
     * ```typescript
     * autofill.browserAutofillEnabled = true;
     * ```
     */
    get browserAutofillEnabled(): boolean;
    set browserAutofillEnabled(enable: boolean);
    retrieveFeature: AddressAutofillFeatureSuggestion;
    /**
     * A callback providing the opportunity to validate and/or manipulate the input text before it triggers a search, for example by using a regular expression.
     * If a truthy string value is returned, it will be passed into the underlying search API. If `null`, `undefined` or empty string is returned, no search request will be performed.
     *
     * @name interceptSearch
     * @instance
     * @memberof MapboxAddressAutofill
     * @example
     * Enable search only when the input value length is more than 3 characters.
     * ```typescript
     * search.interceptSearch = (val) => val?.length > 3 ? val : null;
     * ```
     */
    interceptSearch: (val: string) => string;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    /** @section {Methods} */
    /**
     * Focuses the wrapped input element.
     */
    focus(): void;
    /**
     * Trigger side effects from a retrieve event with a simulated result.
     * Used by {@link confirmAddress} when a suggested addresses is accepted.
     *
     * @ignore
     */
    simulateRetrieve(feature: AddressAutofillFeatureSuggestion): void;
}
declare global {
    interface Window {
        MapboxAddressAutofill: typeof MapboxAddressAutofill;
    }
}
export {};
