import { SearchBoxOptions, SearchBoxRetrieveResponse, SearchBoxSuggestion, SearchBoxSuggestionResponse } from '@mapbox/search-js-core';
import mapboxgl from 'mapbox-gl';
import { MapboxSearchListbox } from './MapboxSearchListbox';
import { HTMLScopedElement } from './HTMLScopedElement';
import { Theme } from '../theme';
import { MapboxHTMLEvent } from '../MapboxHTMLEvent';
import { PopoverOptions } from '../utils/popover';
/**
 * Options to configure component-specific Search behavior
 * @typedef MapboxSearchBoxComponentOptions
 */
export interface MapboxSearchBoxComponentOptions {
    /**
     * Allow the user to query a coordinate string (e.g. "lng,lat") to get a reverse search result.
     */
    allowReverse?: boolean;
    /**
     * If true, the coordinates in the query string are expected to be (lat,lng) instead of (lng,lat).
     */
    flipCoordinates?: boolean;
}
export declare type MapboxSearchListboxSearchType = MapboxSearchListbox<SearchBoxSuggestion>;
declare type SearchEventTypes = {
    /**
     * Fired when the user is typing and is provided a list of suggestions.
     *
     * The underlying response from {@link SearchBoxCore} is passed as the event's detail.
     *
     * @event suggest
     * @instance
     * @memberof MapboxSearchBox
     * @type {SearchBoxSuggestionResponse}
     * @example
     * ```typescript
     * search.addEventListener('suggest', (event) => {
     *   const suggestions = event.detail.suggestions;
     *   // ...
     * });
     * ```
     */
    suggest: MapboxHTMLEvent<SearchBoxSuggestionResponse>;
    /**
     * Fired when {@link SearchBoxCore} has errored providing a list of suggestions.
     *
     * The underlying error is passed as the event's detail.
     *
     * @event suggesterror
     * @instance
     * @memberof MapboxSearchBox
     * @type {Error}
     * @example
     * ```typescript
     * search.addEventListener('suggesterror', (event) => {
     *   const error = event.detail;
     *   // ...
     * });
     * ```
     */
    suggesterror: MapboxHTMLEvent<Error>;
    /**
     * Fired when the user has selected a suggestion.
     *
     * The underlying response from {@link SearchBoxCore} is passed as the event's detail.
     *
     * @event retrieve
     * @instance
     * @memberof MapboxSearchBox
     * @type {SearchBoxRetrieveResponse}
     * @example
     * ```typescript
     * search.addEventListener('retrieve', (event) => {
     *   const featureCollection = event.detail;
     *   // ...
     * });
     * ```
     */
    retrieve: MapboxHTMLEvent<SearchBoxRetrieveResponse>;
    /**
     * Fired when the user has changed the `<input>` text.
     *
     * The new input value is passed as the event's detail.
     *
     * @event input
     * @instance
     * @memberof MapboxSearchBox
     * @type {string}
     * @example
     * ```typescript
     * search.addEventListener('input', (event) => {
     *   if (e.target !== e.currentTarget) return;
     *   const searchText = event.detail;
     *   // ...
     * });
     * ```
     */
    input: MapboxHTMLEvent<string>;
    /**
     * Fired when the user has cleared the <input> box,
     * either by deleting all text or clicking the "Clear" icon.
     *
     * @event clear
     * @instance
     * @memberof MapboxSearchBox
     * @example
     * ```typescript
     * search.addEventListener('clear', () => {
     *   console.log('search box cleared');
     *   // ...
     * });
     * ```
     */
    clear: MapboxHTMLEvent<unknown>;
};
/**
 * `MapboxSearchBox`, also available as the element `<mapbox-search-box>`,
 * is an element that lets you search for places, addresses, and landmarks using
 * the [Mapbox Search Box API](https://docs.mapbox.com/api/search/search-box/).
 *
 * It can control a [Mapbox GL JS](https://docs.mapbox.com/mapbox-gl-js/guides/) map
 * to zoom to the selected result.
 *
 * Additionally, `MapboxSearchBox` implements the [IControl](https://www.mapbox.com/mapbox-gl-js/api/markers/#icontrol)
 * interface.
 *
 * To use this element, you must have a [Mapbox access token](https://www.mapbox.com/help/create-api-access-token/).
 *
 * @class MapboxSearchBox
 * @example
 * ```typescript
 * const search = new MapboxSearchBox();
 * search.accessToken = 'YOUR_MAPBOX_ACCESS_TOKEN';
 * map.addControl(search);
 * ```
 * @example
 * <mapbox-search-box
 *   access-token="YOUR_MAPBOX_ACCESS_TOKEN"
 *   proximity="0,0"
 * >
 * </mapbox-search-box>
 */
export declare class MapboxSearchBox extends HTMLScopedElement<SearchEventTypes> implements mapboxgl.IControl {
    #private;
    /**
     * This is read by the Web Components API to affect the
     * {@link MapboxSearchBox#attributeChangedCallback} below.
     *
     * All of these are passthroughs to the underlying {@link MapboxSearchListbox}.
     *
     * @ignore
     */
    static observedAttributes: string[];
    /**
     * The [Mapbox access token](https://docs.mapbox.com/help/glossary/access-token/) to use for all requests.
     *
     * @name accessToken
     * @instance
     * @memberof MapboxSearchBox
     * @example
     * ```typescript
     * search.accessToken = 'pk.my-mapbox-access-token';
     * ```
     */
    get accessToken(): string;
    set accessToken(newToken: string);
    /**
     * The value of the input element.
     *
     * @name value
     * @instance
     * @memberof MapboxSearchBox
     * @example
     * ```typescript
     * console.log(search.value);
     * ```
     */
    get value(): string;
    set value(newValue: string);
    /**
     * The `<input>` element wrapped by the autofill component.
     *
     * @name input
     * @instance
     * @memberof MapboxSearchBox
     * @type {HTMLInputElement}
     */
    get input(): HTMLInputElement;
    protected get template(): HTMLTemplateElement;
    protected get templateStyle(): string;
    protected get templateUserStyle(): string;
    /**
     * API-specific options to pass to the underlying {@link SearchBoxCore} interface.
     *
     * @name options
     * @instance
     * @memberof MapboxSearchBox
     * @type {SearchBoxOptions}
     * @example
     * ```typescript
     * search.options = {
     *  language: 'en',
     *  country: 'US',
     * };
     * ```
     */
    options: Partial<SearchBoxOptions>;
    /**
     * Options defining the behavior of web component or its underlying search functionality.
     * Distinct from the {@link SearchBoxOptions} options, these do not correspond to the core API specification.
     *
     * @name componentOptions
     * @instance
     * @memberof MapboxSearchBox
     * @type {MapboxSearchBoxComponentOptions}
     * @example
     * ```typescript
     * search.componentOptions = {
     *  allowReverse: true,
     *  flipCoordinates: true
     * };
     * ```
     */
    componentOptions: Partial<MapboxSearchBoxComponentOptions>;
    /**
     * The {@link Theme} to use for styling the suggestion box and search box.
     *
     * @name theme
     * @instance
     * @memberof MapboxSearchBox
     * @type {Theme}
     * @example
     * ```typescript
     * search.theme = {
     *   variables: {
     *     colorPrimary: 'myBrandRed'
     *   },
     *   cssText: ".Input:active { opacity: 0.9; }"
     * };
     * ```
     */
    get theme(): Theme;
    set theme(theme: Theme);
    /**
     * The {@link PopoverOptions} to define popover positioning.
     *
     * @name popoverOptions
     * @instance
     * @memberof MapboxSearchBox
     * @type {PopoverOptions}
     * @example
     * ```typescript
     * search.popoverOptions = {
     *   placement: 'top-start',
     *   flip: true,
     *   offset: 5
     * };
     * ```
     */
    get popoverOptions(): Partial<PopoverOptions>;
    set popoverOptions(newOptions: Partial<PopoverOptions>);
    /**
     * The input element's placeholder text. The default value may be localized if {@link SearchBoxOptions#language} is set.
     *
     * @name placeholder
     * @instance
     * @memberof MapboxSearchBox
     * @type {string}
     */
    get placeholder(): string;
    set placeholder(text: string);
    /**
     * A callback providing the opportunity to validate and/or manipulate the input text before it triggers a search, for example by using a regular expression.
     * If a truthy string value is returned, it will be passed into the underlying search API. If `null`, `undefined` or empty string is returned, no search request will be performed.
     *
     * @name interceptSearch
     * @instance
     * @memberof MapboxSearchBox
     * @example
     * Enable search only when the input value length is more than 3 characters.
     * ```typescript
     * search.interceptSearch = (val) => val?.length > 3 ? val : null;
     * ```
     */
    interceptSearch: (val: string) => string;
    /** @section {Map settings} */
    /**
     * A [mapbox-gl](https://github.com/mapbox/mapbox-gl-js) instance to use when creating [Markers](https://docs.mapbox.com/mapbox-gl-js/api/#marker). Required if {@link MapboxSearchBox#marker} is `true`.
     *
     * @name mapboxgl
     * @instance
     * @memberof MapboxSearchBox
     */
    mapboxgl: typeof mapboxgl;
    /**
     * If `true`, a [Marker](https://docs.mapbox.com/mapbox-gl-js/api/#marker) will be added to the map at the location of the user-selected result using a default set of Marker options.  If the value is an object, the marker will be constructed using these options. If `false`, no marker will be added to the map. Requires that {@link MapboxSearchBox#mapboxgl} also be set.
     *
     * @name marker
     * @instance
     * @memberof MapboxSearchBox
     * @type {boolean | mapboxgl.MarkerOptions}
     * @example
     * ```typescript
     * search.marker = {
     *   color: 'red',
     *   draggable: true
     * };
     * ```
     */
    marker: boolean | mapboxgl.MarkerOptions;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    /** @section {Methods} */
    /**
     * Focuses the input element.
     */
    focus(): void;
    /**
     * Sets the input text and triggers a search programmatically
     */
    search(text: string): void;
    /** @section {Map binding} */
    /**
     * Connects the search box to a [Map](https://docs.mapbox.com/mapbox-gl-js/api/#map),
     * which handles both setting proximity and zoom after a suggestion click.
     *
     * @example
     * ```typescript
     * const search = new MapboxSearchBox();
     * search.bindMap(map);
     * ```
     */
    bindMap(map: mapboxgl.Map): void;
    /**
     * Unbinds the search box from a [Map](https://docs.mapbox.com/mapbox-gl-js/api/#map).
     */
    unbindMap(): void;
    onAdd(map: mapboxgl.Map): HTMLElement;
    onRemove(): void;
    getDefaultPosition(): string;
}
declare global {
    interface Window {
        MapboxSearchBox: typeof MapboxSearchBox;
    }
}
export {};
